@@ -99,6 +99,8 @@ class EmsCliDump:
         output_path: str,
         variant_master_name: Optional[str] = None,
         variant_master_id: Optional[str] = None,
+        objectclasses: Optional[str] = None,
+        variants: Optional[str] = None,
         extension: str = "gpkg",
     ):
         logger.info("Starting dump..")
@@ -144,7 +146,7 @@ class EmsCliDump:
             selected_variant = next(
                 variant
                 for variant in variants_list
-                if variant["id"] == variant_master_id
+                if variant["id"] == int(variant_master_id)
             )
             logger.debug(
                 "Found this variant using id %s as selection: %s",
@@ -161,20 +163,37 @@ class EmsCliDump:
             output_path,
         )
 
-        for variant in selected_variant["children"]:
+        exported_variants = []
+        if variants is not None:
+            exported_variants = variants.split(",")
+        else:
+            exported_variants = selected_variant["children"]
 
-            variant_id = variant["id"]
-            variant_name = variant["variant_name"]
+        for variant in exported_variants:
 
-            logger.info("Current variant %s with id %s", variant_name, variant_id)
+            try:
+                variant_id = variant["id"]
+            except TypeError:
+                variant_id = int(variant)
+                if variant_id == int(variant_master_id):
+                    continue
 
-            variant_geopackage = "variant-{0}-{1}.{2}".format(
-                variant_name, variant_id, extension
-            )
+            logger.info("Current variant id %s", variant_id)
+
+            variant_geopackage = "variant-{0}.{1}".format(variant_id, extension)
             variant_geopackage_path = Path(output_path) / variant_geopackage
 
-            for objectclass in self.project.objectclasses:
-                logger.debug("Processing objectclass %s", objectclass)
+            export_objectclasses = []
+            if objectclasses is not None:
+                export_objectclasses = objectclasses.split(",")
+            else:
+                export_objectclasses = self.project.objectclasses
+
+            for objectclass in export_objectclasses:
+                logger.info("Processing objectclass %s", objectclass)
+
+                if isinstance(objectclass, str):
+                    objectclass = self.project.objectclass(objectclass)
 
                 layers: Optional[List[EmsLayer]] = objectclass.layers
                 if layers is not None:
@@ -218,9 +237,7 @@ class EmsCliDump:
 
                                 if extension == "csv":
                                     csvpackage = "{0}.{1}".format(str(layer), extension)
-                                    variant_dirname = "variant-{0}-{1}".format(
-                                        variant_name, variant_id
-                                    )
+                                    variant_dirname = "variant-{0}".format(variant_id)
                                     variant_path = Path(output_path) / Path(
                                         variant_dirname
                                     )
